--[[
DewDropDown.lua
Defines the table listings for the dropdown lists.
]]

--Invoke all libraries
local BabbleBoss = LibStub("LibBabble-Boss-3.0"):GetLookupTable();
local BabbleZone = LibStub("LibBabble-Zone-3.0"):GetLookupTable();
local BabbleFaction = LibStub("LibBabble-Faction-3.0"):GetLookupTable();
local BabbleClass = LibStub("LibBabble-Class-3.0"):GetLookupTable();
local BabbleInventory = LibStub("LibBabble-Inventory-3.0"):GetLookupTable();
local AL = LibStub("AceLocale-3.0"):GetLocale("AtlasLoot");

--This is a multi-layer table defining the main loot listing.
--Entries have the text to display, loot table or sub table to link to and if the link is to a loot table or sub table
AtlasLoot_DewDropDown = {
	[1] = {
		[AL["Classic Instances"]] = {
			[1] = {
				{ BabbleZone["Blackfathom Deeps"], "BlackfathomDeeps1", "Table" },
			},
			[2] = {
				{ BabbleZone["Blackrock Depths"], "BlackrockDepths", "Submenu" },
			},
			[3] = {
				{ BabbleZone["Lower Blackrock Spire"], "LowerBlackrock", "Submenu" },
			},
			[4] = {
				{ BabbleZone["Upper Blackrock Spire"], "UpperBlackrock", "Submenu" },
			},
			[5] = {
				{ BabbleZone["Blackwing Lair"], "BlackwingLair", "Submenu" },
			},
			[6] = {
				{ BabbleZone["The Deadmines"], "TheDeadmines1", "Table" },
			},
			[7] = {
				[BabbleZone["Dire Maul"]] = {
					{ BabbleZone["Dire Maul (East)"], "DireMaulEast", "Submenu" },
					{ BabbleZone["Dire Maul (West)"], "DireMaulWest", "Submenu" },
					{ BabbleZone["Dire Maul (North)"], "DireMaulNorth", "Submenu" },
				},
			},
			[8] = {
				{ BabbleZone["Gnomeregan"], "Gnomeregan1", "Table" },
			},
			[9] = {
				{ BabbleZone["Maraudon"], "Maraudon1", "Table" },
			},
			[10] = {
				{ BabbleZone["Molten Core"], "MoltenCore", "Submenu" },
			},
			[11] = {
				{ BabbleZone["Onyxia's Lair"], "Onyxia", "Table" },
			},
			[12] = {
				{ BabbleZone["Ragefire Chasm"], "RagefireChasm", "Table" },
			},
			[13] = {
				{ BabbleZone["Razorfen Downs"], "RazorfenDowns1", "Table" },
			},
			[14] = {
				{ BabbleZone["Razorfen Kraul"], "RazorfenKraul1", "Table" },
			},
			[15] = {
				{ BabbleZone["Ruins of Ahn'Qiraj"], "RuinsofAQ", "Submenu" },
			},
			[16] = {
				{ BabbleZone["Scarlet Monastery"], "Scarlet Monastery", "Submenu" },
			},
			[17] = {
				{ BabbleZone["Scholomance"], "Scholomance", "Submenu" },
			},
			[18] = {
				{ BabbleZone["Shadowfang Keep"], "ShadowfangKeep1", "Table" },
			},
			[19] = {
				{ BabbleZone["The Stockade"], "TheStockade", "Table" },
			},
			[20] = {
				{ BabbleZone["Stratholme"], "Stratholme", "Submenu" },
			},
			[21] = {
				{ BabbleZone["Temple of Ahn'Qiraj"], "TempleofAQ", "Submenu" },
			},
			[22] = {
				{ BabbleZone["The Temple of Atal'Hakkar"], "SunkenTemple", "Submenu" },
			},
			[23] = {
				{ BabbleZone["Uldaman"], "Uldaman", "Submenu" },
			},
			[24] = {
				{ BabbleZone["Wailing Caverns"], "WailingCaverns1", "Table" },
			},
			[25] = {
				{ BabbleZone["Zul'Farrak"], "ZulFarrak", "Submenu" },
			},
			[26] = {
				{ BabbleZone["Zul'Gurub"], "ZulGurub", "Submenu" },
			},
		},
	},
	[2] = {
		[AL["BC Instances"]] = {
			[1] = {
				[BabbleZone["Auchindoun"]] = {
					{ BabbleZone["Mana-Tombs"], "AuchManaTombs", "Submenu" },
					{ BabbleZone["Auchenai Crypts"], "AuchCrypts", "Submenu" },
					{ BabbleZone["Sethekk Halls"], "AuchSethekk", "Submenu" },
					{ BabbleZone["Shadow Labyrinth"], "AuchShadowLab", "Submenu" },
				}, 
			},
			[2] = {
				{ BabbleZone["Black Temple"], "BlackTemple", "Submenu" },
			},
			[3] = {
				[BabbleZone["Caverns of Time"]] = {
					{ BabbleZone["Old Hillsbrad Foothills"], "CoTOldHillsbrad", "Submenu" },
					{ BabbleZone["The Black Morass"], "CoTBlackMorass", "Submenu" },
					{ BabbleZone["Hyjal Summit"], "CoTHyjal", "Submenu" },
				},
			},
			[4] = {
				[BabbleZone["Coilfang Reservoir"]] = {
					{ BabbleZone["The Slave Pens"], "CFRSlavePens", "Submenu" },
					{ BabbleZone["The Underbog"], "CFRUnderbog", "Submenu" },
					{ BabbleZone["The Steamvault"], "CFRSteamvault", "Submenu" },
					{ BabbleZone["Serpentshrine Cavern"], "CFRSerpentshrine", "Submenu" },
				},
			},
			[5] = {
				{ BabbleZone["Gruul's Lair"], "Gruul", "Submenu" },
			},
			[6] = {
				[BabbleZone["Hellfire Citadel"]] = {
					{ BabbleZone["Hellfire Ramparts"], "HCRamparts", "Submenu" },
					{ BabbleZone["The Blood Furnace"], "HCFurnace", "Submenu" },
					{ BabbleZone["The Shattered Halls"], "HCShatteredHalls", "Submenu" },
					{ BabbleZone["Magtheridon's Lair"], "HCMagtheridon", "Table" },
				}, 
			},
			[7] = {
				{ BabbleZone["Karazhan"], "Karazhan", "Submenu" },
			},
			[8] = {
				{ BabbleZone["Magisters' Terrace"], "MagistersTerrace", "Submenu" },
			},
			[9] = {
				{ BabbleZone["Sunwell Plateau"], "SunwellPlateau", "Submenu" },
			},
			[10] = {
				[BabbleZone["Tempest Keep"]] = {
					{ BabbleZone["The Mechanar"], "TKMech", "Submenu" },
					{ BabbleZone["The Botanica"], "TKBot", "Submenu" },
					{ BabbleZone["The Arcatraz"], "TKArc", "Submenu" },
					{ BabbleZone["The Eye"], "TKEye", "Submenu" },
				},
			},
			[11] = {
				{ BabbleZone["Zul'Aman"], "ZulAman", "Submenu" },
			},
		},
	},
	[3] = {
		[AL["WotLK Instances"]] = {
			[1] = {
				{ BabbleZone["Ahn'kahet: The Old Kingdom"], "Ahnkahet", "Submenu" },
			},
			[2] = {
				{ BabbleZone["Azjol-Nerub"], "AzjolNerub", "Submenu" },
			},
			[3] = {
				{ BabbleZone["Caverns of Time"]..": "..BabbleZone["The Culling of Stratholme"], "CoTStratholme", "Submenu" },
			},
			[4] = {
				{ BabbleZone["Drak'Tharon Keep"], "DrakTharonKeep", "Submenu" },
			},
			[5] = {
				{ BabbleZone["Gundrak"], "Gundrak", "Submenu" },
			},
			[6] = {
				{ BabbleZone["Halls of Lightning"], "HallsofLightning", "Submenu" },
			},
			[7] = {
				{ BabbleZone["Halls of Stone"], "HallsofStone", "Submenu" },
			},
			[8] = {
				{ BabbleZone["Naxxramas"], "Naxxramas80", "Submenu" },
			},
			[9] = {
				{ BabbleZone["The Eye of Eternity"], "Malygos", "Table" },
			},
			[10] = {
				{ BabbleZone["The Nexus"], "TheNexus", "Submenu" },
			},
			[11] = {
				{ BabbleZone["The Obsidian Sanctum"], "Sartharion", "Table" },
			},
			[12] = {
				{ BabbleZone["The Oculus"], "TheOculus", "Submenu" },
			},
			[13] = {
				{ BabbleZone["Ulduar"], "Ulduar", "Submenu" },
			},
			[14] = {
				{ BabbleZone["Utgarde Keep"], "UtgardeKeep", "Submenu" },
			},
			[15] = {
				{ BabbleZone["Utgarde Pinnacle"], "UtgardePinnacle", "Submenu" },
			},
			[16] = {
				{ BabbleZone["Vault of Archavon"], "Archavon", "Table" },
			},
			[17] = {
				{ BabbleZone["The Violet Hold"], "TheVioletHold", "Submenu" },
			},
		},
	},
	[4] = {
		[AL["Crafting"]] = {
			[1] = { { (GetSpellInfo(2259)), "Alchemy", "Submenu" }, },
			[2] = { { (GetSpellInfo(2018)), "BlackSmithing", "Submenu" }, },
			[3] = { { (GetSpellInfo(2550)), "Cooking1", "Table" }, },
			[4] = { { (GetSpellInfo(7411)), "Enchanting", "Submenu" }, },
			[5] = { { (GetSpellInfo(4036)), "Engineering", "Submenu" }, },
			[6] = { { (GetSpellInfo(3273)), "FirstAid1", "Table" }, },
			[7] = { { (GetSpellInfo(45357)), "Inscription", "Submenu" }, },
			[8] = { { (GetSpellInfo(25229)), "Jewelcrafting", "Submenu" }, },
			[9] = { { (GetSpellInfo(2108)), "Leatherworking", "Submenu" }, },
			[10] = { { (GetSpellInfo(2575)), "Mining1", "Table" }, },
			[11] = { { (GetSpellInfo(3908)), "Tailoring", "Submenu" }, },
			[12] = {
				[AL["Crafted Sets"]] = {
					{ (GetSpellInfo(2018)), "CraftSetBlacksmith", "Submenu" },
					{ (GetSpellInfo(2108)), "CraftSetLeatherwork", "Submenu" },
					{ (GetSpellInfo(3908)), "CraftSetTailor", "Submenu" },
				},
			},
			[13] = { { AL["Crafted Epic Weapons"], "CraftedWeapons1", "Table" }, },
			[14] = { { AL["Crafting Daily Quests"], "CraftingDaily", "Submenu" }, },
		},
	},
	[5] = {
		[AL["Sets/Collections"]] = {
			[1] = {
				{ AL["Badge of Justice Rewards"], "BadgeofJusticeRewards", "Submenu" },
			},
			[2] = {
				{ AL["BoE World Epics"], "BoEWorldEpics", "Submenu" },
			},
			[3] = {
				{ AL["Dungeon 1/2 Sets"], "DungeonSets12", "Submenu" },
			},
			[4] = {
				{ AL["Dungeon 3 Sets"], "DungeonSets3", "Submenu" },
			},
			[5] = {
				{ AL["Emblem of Heroism Rewards"], "EmblemofHeroism", "Table" },
			},
			[6] = {
				{ AL["Emblem of Valor Rewards"], "EmblemofValor", "Table" },
			},
			[7] = {
				{ AL["Legendary Items"], "Legendaries", "Table" }, 
			},
			[8] = {
				[AL["Mounts"]] = {
					{ AL["Classic Mounts"], "MountsClassic", "Submenu" },
					{ AL["The Burning Crusade Mounts"], "MountsBC", "Submenu" },
					{ AL["Wrath of the Lich King Mounts"], "MountsLichKing", "Submenu" },
				},
			},
			[9] = {
				{ AL["Non-Combat Pets"], "Pets", "Submenu" },
			},
			[10] = {
				[AL["Misc Sets"]] = {
					{ AL["Classic Sets"], "SETSCLASSIC", "Table" },
					{ AL["Burning Crusade Sets"], "SETSBURNINGCURSADE", "Table" },
				},
			},
			[11] = {
				{ AL["Ruins of Ahn'Qiraj Sets"], "AQ20Sets1", "Table" },
			},
			[12] = {
				{ AL["Tabards"], "Tabards3", "Table" }, 
			},
			[13] = {
				{ AL["Temple of Ahn'Qiraj Sets"], "AQ40Sets1", "Table" },
			},
			[14] = {
				{ AL["Tier 1/2 Sets"], "T1T2Sets", "Submenu" },
			},
			[15] = {
				{ AL["Tier 3 Sets"], "T3Sets", "Submenu" },
			},
			[16] = {
				{ AL["Tier 4/5/6 Sets"], "T456Sets", "Submenu" },
			},
			[17] = {
				{ AL["Tier 7/8 Sets"], "Naxx10Sets", "Submenu" },
			},
			[18] = {
				{ AL["Upper Deck Card Game Items"], "CardGame1", "Table" }, 
			},
			[19] = {
				{ AL["Zul'Gurub Sets"], "ZGSets1", "Table" },
			},

		},
	},
	[6] = {
		[AL["PvP Rewards"]] = {
			[1] = {
				{ AL["Arena PvP Sets"], "ArenaPvPRewards", "Submenu" },
			},
			[2] = {
				{ AL["PvP Rewards (Level 60)"], "PvPLvl60Rewards", "Submenu" },
			},
			[3] = {
				{ AL["PvP Rewards (Level 70)"], "PvPLvl70Rewards", "Submenu" },
			},
			[4] = {
				{ AL["PvP Rewards (Level 80)"], "PvPLvl80Rewards", "Submenu" },
			},
			[5] = {
				{ BabbleZone["Alterac Valley"], "AVRewards", "Submenu" },
			},
			[6] = {
				{ BabbleZone["Arathi Basin"], "ABRewards", "Submenu" },
			},
			[7] = {
				{ AL["Arathi Basin Sets"], "ABSets", "Submenu" },
			},
			[8] = {
				{ BabbleZone["Warsong Gulch"], "WSGRewards", "Submenu" },
			},
			[9] = {
				{ AtlasLoot_TableNames["Hellfire"][1], "Hellfire", "Table" },
			},
			[10] = {
				{ AtlasLoot_TableNames["Nagrand1"][1], "Nagrand1", "Table" },
			},
			[11] = {
				{ AtlasLoot_TableNames["Terokkar"][1], "Terokkar", "Table" },
			},
			[12] = {
				{ AtlasLoot_TableNames["Zangarmarsh"][1], "Zangarmarsh", "Table" },
			},
			[13] = {
				{ AtlasLoot_TableNames["VentureBay1"][1], "VentureBay1", "Table" },
			},
			[14] = {
				{ AtlasLoot_TableNames["LakeWintergrasp1"][1], "LakeWintergrasp1", "Table" },
			},
		},
	},
	[7] = {
		{ AL["World Bosses"], "WorldBosses", "Submenu" },
	},
	[8] = {
		[AL["Reputation Factions"]] = {
			[1] = {
				{ AL["Original Factions"], "WoWFactions", "Submenu" },
			},
			[2] = {
				{ AL["BC Factions"], "BCFactions", "Submenu" },
			},
			[3] = {
				{ AL["WotLK Factions"], "WotLKFactions", "Submenu" },
			}, 
		},
	},
	[9] = {
		[AL["World Events"]] = {
			[1] = {
				{ AL["Abyssal Council"], "AbyssalCouncil", "Submenu" },
			},
			[2] = {
				{ "Argent Tournament", "ArgentTournament1", "Table" },
			},
			[3] = {
				{ AL["Bash'ir Landing Skyguard Raid"], "BashirLanding", "Table" },
			},
			[4] = {
				{ AL["Brewfest"], "Brewfest1", "Table" },
			},
			[5] = {
				{ AL["Children's Week"], "ChildrensWeek", "Table" },
			},
			[6] = {
				{ BabbleFaction["Darkmoon Faire"], "DARKMOONMENU", "Table" },
			},
			[7] = {
				{ AL["Elemental Invasion"], "ElementalInvasion", "Table" },
			},
			[8] = {
				{ AL["Ethereum Prison"], "EthereumPrison", "Submenu" },
			},
			[9] = {
				{ AL["Feast of Winter Veil"], "Winterviel1", "Table" },
			},
			[10] = {
				{ AL["Gurubashi Arena Booty Run"], "GurubashiArena", "Table" },
			},
			[11] = {
				{ AL["Hallow's End"], "Halloween1", "Table" },
			},
			[12] = {
				{ AL["Harvest Festival"], "HarvestFestival", "Table" },
			},
			[13] = {
				{ AL["Love is in the Air"], "Valentineday", "Table" },
			},
			[14] = {
				{ AL["Lunar Festival"], "LunarFestival1", "Table" },
			},
			[15] = {
				{ AL["Midsummer Fire Festival"], "MidsummerFestival", "Table" },
			},
			[16] = {
				{ AL["Noblegarden"], "Noblegarden", "Table" },
			},
			[17] = {
				{ AL["Scourge Invasion"], "ScourgeInvasionEvent1", "Table" },
			},
			[18] = {
				{ AL["Shartuul"], "Shartuul", "Table" },
			},
			[19] = {
				{ AL["Skettis"], "Skettis", "Submenu" },
			},
			[20] = {
				{ AL["Stranglethorn Fishing Extravaganza"], "FishingExtravaganza", "Table" },
			},
		},
	},
};

--This table defines all the subtables needed for the full menu
--Each sub table entry contains the text entry and the loot table that goes wih it
AtlasLoot_DewDropDown_SubTables = {
	["BlackrockDepths"] = {
		{ "", "BRDPyron" },
		{ "", "BRDLordRoccor" },
		{ "", "BRDHighInterrogatorGerstahn" },
		{ "", "BRDArena" },
		{ "", "BRDTheldren" },
		{ "", "BRDHoundmaster" },
		{ "", "BRDPyromantLoregrain" },
		{ "", "BRDTheVault" },
		{ "", "BRDWarderStilgiss" },
		{ "", "BRDVerek" },
		{ "", "BRDFineousDarkvire" },
		{ "", "BRDLordIncendius" },
		{ "", "BRDBaelGar" },
		{ "", "BRDGeneralAngerforge" },
		{ "", "BRDGolemLordArgelmach" },
		{ "", "BRDGuzzler" },
		{ "", "CorenDirebrew" },
		{ "", "BRDFlamelash" },
		{ "", "BRDPanzor" },
		{ "", "BRDTomb" },
		{ "", "BRDMagmus" },
		{ "", "BRDImperatorDagranThaurissan" },
		{ "", "BRDPrincess" },
		{ "", "BRDBSPlans" },
		{ "", "BRDTrash" },
		{ "", "VWOWSets1" },
	},
	["LowerBlackrock"] = {
		{ "", "LBRSSpirestoneButcher" },
		{ "", "LBRSOmokk" },
		{ "", "LBRSSpirestoneLord" },
		{ "", "LBRSLordMagus" },
		{ "", "LBRSVosh" },
		{ "", "LBRSVoone" },
		{ "", "LBRSGrayhoof" },
		{ "", "LBRSGrimaxe" },
		{ "", "LBRSSmolderweb" },
		{ "", "LBRSCrystalFang" },
		{ "", "LBRSDoomhowl" },
		{ "", "LBRSZigris" },
		{ "", "LBRSHalycon" },
		{ "", "LBRSSlavener" },
		{ "", "LBRSBashguud" },
		{ "", "LBRSWyrmthalak" },
		{ "", "LBRSFelguard" },
		{ "", "LBRSTrash" },
		{ "", "VWOWSets3" },
	},
	["UpperBlackrock"] = {
		{ "", "UBRSEmberseer" },
		{ "", "UBRSSolakar" },
		{ "", "UBRSFLAME" },
		{ "", "UBRSRunewatcher" },
		{ "", "UBRSAnvilcrack" },
		{ "", "UBRSRend" },
		{ "", "UBRSGyth" },
		{ "", "UBRSBeast" },
		{ "", "UBRSValthalak" },
		{ "", "UBRSDrakkisath" },
		{ "", "UBRSTrash" },
		{ "", "VWOWSets3" },
	},
	["BlackwingLair"] = {
		{ "", "BWLRazorgore" },
		{ "", "BWLVaelastrasz" },
		{ "", "BWLLashlayer" },
		{ "", "BWLFiremaw" },
		{ "", "BWLEbonroc" },
		{ "", "BWLFlamegor" },
		{ "", "BWLChromaggus" },
		{ "", "BWLNefarian" },
		{ "", "BWLTrashMobs" },
	},
	["Karazhan"] = {
		{ "", "KaraAttumen" },
		{ "", "KaraMoroes" },
		{ "", "KaraMaiden" },
		{ "", "KaraOperaEvent" },
		{ "", "KaraCurator" },
		{ "", "KaraIllhoof" },
		{ "", "KaraAran" },
		{ "", "KaraNetherspite" },
		{ "", "KaraNightbane" },
		{ "", "KaraChess" },
		{ "", "KaraPrince" },
		{ "", "KaraNamed" },
		{ "", "KaraTrash" },
	},
	["MagistersTerrace"] = {
		{ "", "SMTFireheart" },
		{ "", "SMTVexallus" },
		{ "", "SMTDelrissa" },
		{ "", "SMTKaelthas" },
	},
	["MoltenCore"] = {
		{ "", "MCLucifron" },
		{ "", "MCMagmadar" },
		{ "", "MCGehennas" },
		{ "", "MCGarr" },
		{ "", "MCShazzrah" },
		{ "", "MCGeddon" },
		{ "", "MCGolemagg" },
		{ "", "MCSulfuron" },
		{ "", "MCMajordomo" },
		{ "", "MCRagnaros" },
		{ "", "MCTrashMobs" },
		{ "", "MCRANDOMBOSSDROPPS" },
	},
	["Scarlet Monastery"] = {
		{ BabbleZone["Armory"], "SMHerod" },
		{ "", "SMCathedral" },
		{ "", "SMGraveyard" },
		{ "", "SMLibrary" },
		{ "", "SMTrash" },
		{ AL["Set: Chain of the Scarlet Crusade"], "VWOWSets1" },
	},
	["Scholomance"] = {
		{ "", "SCHOLOBloodStewardofKirtonos" },
		{ "", "SCHOLOKirtonostheHerald" },
		{ "", "SCHOLOJandiceBarov" },
		{ "", "SCHOLORattlegore" },
		{ "", "SCHOLODeathKnight" },
		{ "", "SCHOLOMarduk" },
		{ "", "SCHOLOVectus" },
		{ "", "SCHOLORasFrostwhisper" },
		{ "", "SCHOLOKormok" },
		{ "", "SCHOLOInstructorMalicia" },
		{ "", "SCHOLODoctorTheolenKrastinov" },
		{ "", "SCHOLOLorekeeperPolkelt" },
		{ "", "SCHOLOTheRavenian" },
		{ "", "SCHOLOLordAlexeiBarov" },
		{ "", "SCHOLOLadyIlluciaBarov" },
		{ "", "SCHOLODarkmasterGandling" },
		{ "", "SCHOLOTrash" },
		{ AL["Set: Necropile Raiment"], "VWOWScholo" },
		{ AL["Set: Cadaverous Garb"], "VWOWScholo" },
		{ AL["Set: Bloodmail Regalia"], "VWOWScholo" },
		{ AL["Set: Deathbone Guardian"], "VWOWScholo" },
	},
	["Stratholme"] = {
		{ BabbleBoss["Skul"], "STRATSkull" },
		{ AtlasLoot_TableNames["STRATStratholmeCourier"][1], "STRATStratholmeCourier" },
		{ BabbleBoss["Fras Siabi"], "STRATFrasSiabi" },
		{ AtlasLoot_TableNames["STRATAtiesh"][1], "STRATAtiesh" },
		{ BabbleBoss["Hearthsinger Forresten"], "STRATHearthsingerForresten" },
		{ BabbleBoss["The Unforgiven"], "STRATTheUnforgiven" },
		{ BabbleBoss["Timmy the Cruel"], "STRATTimmytheCruel" },
		{ AtlasLoot_TableNames["STRATMalorsStrongbox"][1], "STRATMalorsStrongbox" },
		{ BabbleBoss["Crimson Hammersmith"], "STRATCrimsonHammersmith" },
		{ AtlasLoot_TableNames["STRATBSPlansSerenity"][1], "STRATBSPlansSerenity" },
		{ BabbleBoss["Cannon Master Willey"], "STRATCannonMasterWilley" },
		{ BabbleBoss["Archivist Galford"], "STRATArchivistGalford" },
		{ BabbleBoss["Balnazzar"], "STRATBalnazzar" },
		{ AL["Sothos and Jarien"], "STRATSothosJarien" },
		{ AtlasLoot_TableNames["STRATStonespine"][1], "STRATStonespine" },
		{ BabbleBoss["Baroness Anastari"], "STRATBaronessAnastari" },
		{ BabbleBoss["Black Guard Swordsmith"], "STRATBlackGuardSwordsmith" },
		{ AtlasLoot_TableNames["STRATBSPlansCorruption"][1], "STRATBSPlansCorruption" },
		{ BabbleBoss["Nerub'enkan"], "STRATNerubenkan" },
		{ BabbleBoss["Maleki the Pallid"], "STRATMalekithePallid" },
		{ BabbleBoss["Magistrate Barthilas"], "STRATMagistrateBarthilas" },
		{ BabbleBoss["Ramstein the Gorger"], "STRATRamsteintheGorger" },
		{ BabbleBoss["Baron Rivendare"], "STRATBaronRivendare" },
		{ AL["Trash Mobs"], "STRATTrash" },
		{ AL["Set: The Postmaster"], "VWOWSets2" },
	},
	["SunkenTemple"] = {
		{ AtlasLoot_TableNames["STSpawnOfHakkar"][1], "STSpawnOfHakkar" },
		{ AtlasLoot_TableNames["STTrollMinibosses"][1], "STTrollMinibosses" },
		{ BabbleBoss["Atal'alarion"], "STAtalalarion" },
		{ BabbleBoss["Dreamscythe"], "STDreamscythe" },
		{ BabbleBoss["Weaver"], "STWeaver"},
		{ BabbleBoss["Avatar of Hakkar"], "STAvatarofHakkar" },
		{ BabbleBoss["Jammal'an the Prophet"], "STJammalan" },
		{ BabbleBoss["Ogom the Wretched"], "STOgom" },
		{ BabbleBoss["Morphaz"], "STMorphaz" },
		{ BabbleBoss["Hazzas"], "STHazzas" },
		{ BabbleBoss["Shade of Eranikus"], "STEranikus" },
		{ AL["Trash Mobs"], "STTrash" },
	},
	["Uldaman"] = {
		{ BabbleBoss["Digmaster Shovelphlange"], "UldShovelphlange" },
		{ AtlasLoot_TableNames["UldBaelog"][1], "UldBaelog" },
		{ BabbleBoss["Revelosh"], "UldRevelosh" },
		{ BabbleBoss["Ironaya"], "UldIronaya" },
		{ BabbleBoss["Ancient Stone Keeper"], "UldAncientStoneKeeper" },
		{ BabbleBoss["Galgann Firehammer"], "UldGalgannFirehammer" },
		{ BabbleBoss["Grimlok"], "UldGrimlok" },
		{ BabbleBoss["Archaedas"], "UldArchaedas" },
		{ AL["Trash Mobs"], "UldTrash" },
	},
	["ZulGurub"] = {
		{ BabbleBoss["High Priestess Jeklik"], "ZGJeklik" },
		{ BabbleBoss["High Priest Venoxis"], "ZGVenoxis" },
		{ BabbleBoss["High Priestess Mar'li"], "ZGMarli" },
		{ BabbleBoss["Bloodlord Mandokir"], "ZGMandokir" },
		{ BabbleZone["Zul'Gurub"], "ZGEdgeofMadness" },
		{ BabbleBoss["Gahz'ranka"], "ZGGahzranka" },
		{ BabbleBoss["High Priest Thekal"], "ZGThekal" },
		{ BabbleBoss["High Priestess Arlokk"], "ZGArlokk" },
		{ BabbleBoss["Jin'do the Hexxer"], "ZGJindo" },
		{ BabbleBoss["Hakkar"], "ZGHakkar" },
		{ AL["Random Boss Loot"], "ZGShared" },
		{ AL["Trash Mobs"], "ZGTrash1" },
		{ AL["ZG Enchants"], "ZGEnchants" },
	},
	["CoTOldHillsbrad"] = {
		{ "", "CoTHillsbradDrake" },
		{ "", "CoTHillsbradSkarloc" },
		{ "", "CoTHillsbradHunter" },
		{ AL["Trash Mobs"], "CoTTrash" },
	},
	["CoTBlackMorass"] = {
		{ "", "CoTMorassDeja" },
		{ "", "CoTMorassTemporus" },
		{ "", "CoTMorassAeonus" },
		{ AL["Trash Mobs"], "CoTTrash" },
	},
	["CoTHyjal"] = {
		{ "", "MountHyjalWinterchill" },
		{ "", "MountHyjalAnetheron" },
		{ "", "MountHyjalKazrogal" },
		{ "", "MountHyjalAzgalor" },
		{ "", "MountHyjalArchimonde" },
		{ AL["Trash Mobs"], "MountHyjalTrash" },
	},
	["DireMaulEast"] = {
		{ BabbleBoss["Pusillin"], "DMEPusillin" },
		{ BabbleBoss["Zevrim Thornhoof"], "DMEZevrimThornhoof" },
		{ BabbleBoss["Hydrospawn"], "DMEHydro" },
		{ BabbleBoss["Lethtendris"], "DMELethtendris" },
		{ BabbleBoss["Pimgib"], "DMEPimgib" },
		{ BabbleBoss["Alzzin the Wildshaper"], "DMEAlzzin" },
		{ BabbleBoss["Isalien"], "DMEIsalien" },
		{ AL["Trash Mobs"], "DMETrash" },
		{ AL["Dire Maul Books"], "DMBooks" },
	},
	["DireMaulWest"] = {
		{ BabbleBoss["Tendris Warpwood"], "DMWTendrisWarpwood" },
		{ BabbleBoss["Illyanna Ravenoak"], "DMWIllyannaRavenoak" },
		{ BabbleBoss["Magister Kalendris"], "DMWMagisterKalendris" },
		{ BabbleBoss["Tsu'zee"], "DMWTsuzee" },
		{ BabbleBoss["Immol'thar"], "DMWImmolthar" },
		{ BabbleBoss["Lord Hel'nurath"], "DMWHelnurath" },
		{ BabbleBoss["Prince Tortheldrin"], "DMWPrinceTortheldrin" },
		{ AL["Trash Mobs"], "DMWTrash" },
		{ AL["Dire Maul Books"], "DMBooks" },
	},
	["DireMaulNorth"] = {
		{ BabbleBoss["Guard Mol'dar"], "DMNGuardMoldar" },
		{ BabbleBoss["Stomper Kreeg"], "DMNStomperKreeg" },
		{ BabbleBoss["Guard Fengus"], "DMNGuardFengus" },
		{ AtlasLoot_TableNames["DMNThimblejack"][1], "DMNThimblejack" },
		{ BabbleBoss["Guard Slip'kik"], "DMNGuardSlipkik" },
		{ BabbleBoss["Captain Kromcrush"], "DMNCaptainKromcrush" },
		{ BabbleBoss["King Gordok"], "DMNKingGordok" },
		{ BabbleBoss["Cho'Rush the Observer"], "DMNChoRush" },
		{ AL["Tribute Run"], "DMNTRIBUTERUN" },
		{ AL["Dire Maul Books"], "DMBooks" },
	},
	["RuinsofAQ"] = {
		{ BabbleBoss["Kurinnaxx"], "AQ20Kurinnaxx" },
		{ BabbleBoss["General Rajaxx"], "AQ20Rajaxx" },
		{ BabbleBoss["Moam"], "AQ20Moam" },
		{ BabbleBoss["Buru the Gorger"], "AQ20Buru" },
		{ BabbleBoss["Ayamiss the Hunter"], "AQ20Ayamiss" },
		{ BabbleBoss["Ossirian the Unscarred"], "AQ20Ossirian" },
		{ AL["Trash Mobs"], "AQ20Trash" },
		{ AL["Class Books"], "AQ20ClassBooks" },
		{ AL["AQ Enchants"], "AQEnchants" },
		{ AL["Ruins of Ahn'Qiraj Sets"], "AQ20Sets1" },
	},
	["TempleofAQ"] = {
		{ BabbleBoss["The Prophet Skeram"], "AQ40Skeram" },
		{ BabbleBoss["The Bug Family"], "AQ40Vem" },
		{ BabbleBoss["Battleguard Sartura"], "AQ40Sartura" },
		{ BabbleBoss["Fankriss the Unyielding"], "AQ40Fankriss" },
		{ BabbleBoss["Viscidus"], "AQ40Viscidus" },
		{ BabbleBoss["Princess Huhuran"], "AQ40Huhuran" },
		{ BabbleBoss["The Twin Emperors"], "AQ40Emperors" },
		{ BabbleBoss["Ouro"], "AQ40Ouro" },
		{ BabbleBoss["C'Thun"], "AQ40CThun" },
		{ AL["Trash Mobs"], "AQ40Trash1" },
		{ AL["AQ Enchants"], "AQEnchants" },
		{ AL["AQ Opening Quest Chain"], "AQOpening" },
	},
	["ZulFarrak"] = {
		{ BabbleBoss["Antu'sul"], "ZFAntusul" },
		{ BabbleBoss["Theka the Martyr"], "ZFThekatheMartyr" },
		{ BabbleBoss["Witch Doctor Zum'rah"], "ZFWitchDoctorZumrah" },
		{ BabbleBoss["Nekrum Gutchewer"], "ZFNekrumGutchewer" },
		{ BabbleBoss["Shadowpriest Sezz'ziz"], "ZFSezzziz" },
		{ BabbleBoss["Dustwraith"], "ZFDustwraith" },
		{ BabbleBoss["Sergeant Bly"], "ZFSergeantBly" },
		{ BabbleBoss["Sandfury Executioner"], "ZFSandfury" },
		{ BabbleBoss["Hydromancer Velratha"], "ZFHydromancerVelratha" },
		{ BabbleBoss["Gahz'rilla"], "ZFGahzrilla" },
		{ BabbleBoss["Chief Ukorz Sandscalp"], "ZFChiefUkorzSandscalp" },
		{ BabbleBoss["Zerillis"], "ZFZerillis" },
		{ AL["Trash Mobs"], "ZFTrash" },
	},
	["AuchManaTombs"] = {
		{ "", "AuchManaPandemonius" },
		{ "", "AuchManaTavarok" },
		{ "", "AuchManaNexusPrince" },
		{ "", "AuchManaYor" },
		{ AL["Trash Mobs"], "AuchTrash" },
	},
	["AuchCrypts"] = {
		{ "", "AuchCryptsShirrak" },
		{ "", "AuchCryptsExarch" },
		{ "", "AuchCryptsAvatar" },
		{ AL["Trash Mobs"], "AuchTrash" },
	},
	["AuchSethekk"] = {
		{ "", "AuchSethekkDarkweaver" },
		{ "", "AuchSethekkTalonKing" },
		{ "", "AuchSethekkRavenGod" },
		{ AL["Trash Mobs"], "AuchTrash" },
	},
	["AuchShadowLab"] = {
		{ "", "AuchShadowHellmaw" },
		{ "", "AuchShadowBlackheart" },
		{ "", "AuchShadowGrandmaster" },
		{ "", "AuchShadowMurmur" },
		{ AL["Trash Mobs"], "AuchTrash" },
	},
	["BlackTemple"] = {
		{ "", "BTNajentus" },
		{ "", "BTSupremus" },
		{ "", "BTAkama" },
		{ "", "BTGorefiend" },
		{ "", "BTBloodboil" },
		{ "", "BTEssencofSouls" },
		{ "", "BTShahraz" },
		{ "", "BTCouncil" },
		{ "", "BTIllidanStormrage" },
		{ AL["BT Patterns/Plans"], "BTPatterns" },
		{ AL["Trash Mobs"], "BTTrash" },
	},
	["CFRSlavePens"] = {
		{ "", "CFRSlaveMennu" },
		{ "", "CFRSlaveRokmar" },
		{ "", "CFRSlaveQuagmirran" },
		{ "", "LordAhune" },
	},
	["CFRUnderbog"] = {
		{ "", "CFRUnderHungarfen" },
		{ "", "CFRUnderGhazan" },
		{ "", "CFRUnderSwamplord" },
		{ "", "CFRUnderStalker" },
	},
	["CFRSteamvault"] = {
		{ "", "CFRSteamThespia" },
		{ "", "CFRSteamSteamrigger" },
		{ "", "CFRSteamWarlord" },
		{ AL["Trash Mobs"], "CFRSteamTrash" },
	},
	["CFRSerpentshrine"] = {
		{ "", "CFRSerpentHydross" },
		{ "", "CFRSerpentLurker" },
		{ "", "CFRSerpentLeotheras" },
		{ "", "CFRSerpentKarathress" },
		{ "", "CFRSerpentMorogrim" },
		{ "", "CFRSerpentVashj" },
		{ AL["Trash Mobs"], "CFRSerpentTrash" },
	},
	["Gruul"] = {
		{ "", "GruulsLairHighKingMaulgar" },
		{ "", "GruulGruul" },
	},
	["HCRamparts"] = {
		{ "", "HCRampWatchkeeper" },
		{ "", "HCRampOmor" },
		{ "", "HCRampVazruden" },
	},
	["HCFurnace"] = {
		{ "", "HCFurnaceMaker" },
		{ "", "HCFurnaceBroggok" },
		{ "", "HCFurnaceBreaker" },
	},
	["HCShatteredHalls"] = {
		{ "", "HCHallsNethekurse" },
		{ "", "HCHallsPorung" },
		{ "", "HCHallsOmrogg" },
		{ "", "HCHallsKargath" },
		{ AL["Trash Mobs"], "HCHallsTrash" },
	},
	["TKMech"] = {
		{ "", "TKMechCacheoftheLegion" },
		{ "", "TKMechCapacitus" },
		{ "", "TKMechSepethrea" },
		{ "", "TKMechCalc" },
		{ AL["Trash Mobs"], "TKTrash" },
	},
	["TKBot"] = {
		{ "", "TKBotSarannis" },
		{ "", "TKBotFreywinn" },
		{ "", "TKBotThorngrin" },
		{ "", "TKBotLaj" },
		{ "", "TKBotSplinter" },
		{ AL["Trash Mobs"], "TKTrash" },
	},
	["TKArc"] = {
		{ "", "TKArcUnbound" },
		{ "", "TKArcScryer" },
		{ "", "TKArcDalliah" },
		{ "", "TKArcHarbinger" },
		{ AL["Trash Mobs"], "TKTrash" },
	},
	["TKEye"] = {
		{ "", "TKEyeAlar" },
		{ "", "TKEyeVoidReaver" },
		{ "", "TKEyeSolarian" },
		{ "", "TKEyeKaelthas" },
		{ "", "TKEyeLegendaries" },
		{ AL["Trash Mobs"], "TKEyeTrash" },
	},
	["ZulAman"] = {
		{ "", "ZANalorakk" },
		{ "", "ZAAkilZon" },
		{ "", "ZAJanAlai" },
		{ "", "ZAHalazzi" },
		{ "", "ZAMalacrass" },
		{ "", "ZAZuljin" },
		{ AL["Timed Reward Chest"], "ZATimedChest" },
		{ AL["Trash Mobs"], "ZATrash" },
	},
	["SunwellPlateau"] = {
		{ "", "SPKalecgos" },
		{ "", "SPBrutallus" },
		{ "", "SPFelmyst" },
		{ "", "SPEredarTwins" },
		{ "", "SPMuru" },
		{ "", "SPKiljaeden" },
		{ "", "SPPatterns" },
		{ AL["Trash Mobs"], "SPTrash" },
	},
	["Ahnkahet"] = {
		{ "", "AhnkahetNadox" },
		{ "", "AhnkahetTaldaram" },
		{ "", "AhnkahetAmanitarHEROIC" },
		{ "", "AhnkahetJedoga" },
		{ "", "AhnkahetVolazj" },
		{ "", "AhnkahetTrash" },
	},
	["AzjolNerub"] = {
		{ "", "AzjolNerubKrikthir" },
		{ "", "AzjolNerubHadronox" },
		{ "", "AzjolNerubAnubarak" },
		{ "", "AzjolNerubTrash" },
	},
	["CoTStratholme"] = {
		{ "", "CoTStratholmeMeathook" },
		{ "", "CoTStratholmeEpoch" },
		{ "", "CoTStratholmeSalramm" },
		{ "", "CoTStratholmeInfiniteCorruptorHEROIC" },
		{ "", "CoTStratholmeMalGanis" },
		{ "", "CoTStratholmeTrash" },
	},
	["DrakTharonKeep"] = {
		{ "", "DrakTharonKeepTrollgore" },
		{ "", "DrakTharonKeepNovos" },
		{ "", "DrakTharonKeepKingDred" },
		{ "", "DrakTharonKeepTharonja" },
		{ "", "DrakTharonKeepTrash" },
	},
	["Gundrak"] = {
		{ "", "GundrakSladran" },
		{ "", "GundrakColossus" },
		{ "", "GundrakMoorabi" },
		{ "", "GundrakEckHEROIC" },
		{ "", "GundrakGaldarah" },
		{ "", "GundrakTrash" },
	},
	["HallsofLightning"] = {
		{ "", "HallsofLightningBjarngrim" },
		{ "", "HallsofLightningVolkhan" },
		{ "", "HallsofLightningIonar" },
		{ "", "HallsofLightningLoken" },
		{ "", "HallsofLightningTrash" },
	},
	["HallsofStone"] = {
		{ "", "HallsofStoneMaiden" },
		{ "", "HallsofStoneKrystallus" },
		{ "", "HallsofStoneTribunal" },
		{ "", "HallsofStoneSjonnir" },
		{ "", "HallsofStoneTrash" },
	},
	["Ulduar"] = {
		{ "", "UlduarLeviathan" },
		{ "", "UlduarIgnis" },
		{ "", "UlduarRazorscale" },
		{ "", "UlduarDeconstructor" },
		{ "", "UlduarIronCouncil" },
		{ "", "UlduarKologarn" },
		{ "", "UlduarAuriaya" },
		{ "", "UlduarHodir" },
		{ "", "UlduarThorim" },
		{ "", "UlduarFreya" },
		{ "", "UlduarMimiron" },
		{ "", "UlduarVezax" },
	},
	["UtgardeKeep"] = {
		{ "", "UtgardeKeepKeleseth" },
		{ "", "UtgardeKeepSkarvald" },
		{ "", "UtgardeKeepIngvar" },
		{ "", "UtgardeKeepTrash" },
	},
	["UtgardePinnacle"] = {
		{ "", "UPSkadi" },
		{ "", "UPYmiron" },
		{ "", "UPSorrowgrave" },
		{ "", "UPPalehoof" },
		{ "", "UPTrash" },
	},
	["TheVioletHold"] = {
		{ "", "VioletHoldErekem" },
		{ "", "VioletHoldZuramat" },
		{ "", "VioletHoldXevozz" },
		{ "", "VioletHoldIchoron" },
		{ "", "VioletHoldMoragg" },
		{ "", "VioletHoldLavanthor" },
		{ "", "VioletHoldCyanigosa" },
		{ "", "VioletHoldTrash" },
	},
	["TheOculus"] = {
		{ "", "OcuDrakos" },
		{ "", "OcuUrom" },
		{ "", "OcuCloudstrider" },
		{ "", "OcuEregos" },
		{ "", "OcuTrash" },
	},
	["Naxxramas80"] = {
		{ AtlasLoot_TableNames["Naxx80Patchwerk"][1].." ("..AL["Construct Quarter"]..")", "Naxx80Patchwerk" },
		{ AtlasLoot_TableNames["Naxx80Grobbulus"][1].." ("..AL["Construct Quarter"]..")", "Naxx80Grobbulus" },
		{ AtlasLoot_TableNames["Naxx80Gluth1"][1].." ("..AL["Construct Quarter"]..")", "Naxx80Gluth1" },
		{ AtlasLoot_TableNames["Naxx80Thaddius"][1].." ("..AL["Construct Quarter"]..")", "Naxx80Thaddius" },
		{ AtlasLoot_TableNames["Naxx80AnubRekhan"][1].." ("..AL["Arachnid Quarter"]..")", "Naxx80AnubRekhan" },
		{ AtlasLoot_TableNames["Naxx80Faerlina"][1].." ("..AL["Arachnid Quarter"]..")", "Naxx80Faerlina" },
		{ AtlasLoot_TableNames["Naxx80Maexxna"][1].." ("..AL["Arachnid Quarter"]..")", "Naxx80Maexxna" },
		{ AtlasLoot_TableNames["Naxx80Razuvious"][1].." ("..AL["Military Quarter"]..")", "Naxx80Razuvious" },
		{ AtlasLoot_TableNames["Naxx80Gothik"][1].." ("..AL["Military Quarter"]..")", "Naxx80Gothik" },
		{ AtlasLoot_TableNames["Naxx80FourHorsemen"][1].." ("..AL["Military Quarter"]..")", "Naxx80FourHorsemen" },
		{ AtlasLoot_TableNames["Naxx80Noth"][1].." ("..AL["Plague Quarter"]..")", "Naxx80Noth" },
		{ AtlasLoot_TableNames["Naxx80Heigan"][1].." ("..AL["Plague Quarter"]..")", "Naxx80Heigan" },
		{ AtlasLoot_TableNames["Naxx80Loatheb"][1].." ("..AL["Plague Quarter"]..")", "Naxx80Loatheb" },
		{ AtlasLoot_TableNames["Naxx80Sapphiron"][1].." ("..AL["Frostwyrm Lair"]..")", "Naxx80Sapphiron" },
		{ AtlasLoot_TableNames["Naxx80KelThuzad"][1].." ("..AL["Frostwyrm Lair"]..")", "Naxx80KelThuzad" },
		{ "", "Naxx80Trash" },
	},
	["TheNexus"] = {
		{ "", "TheNexusTelestra" },
		{ "", "TheNexusAnomalus"},
		{ "", "TheNexusOrmorok" },
		{ "", "TheNexusKolurgStoutbeardHEROIC"},
		{ "", "TheNexusKeristrasza" },
	},
	["WorldBosses"] = {
		{ "", "WorldBossesClassic" },
		{ "", "WorldBossesBC"},
		{ "", "DEmeriss" },
		{ "", "DLethon"},
		{ "", "DTaerar" },
		{ "", "DYsondre" },
	},
	["AbyssalCouncil"] = {
		{ AL["Abyssal Council"].." - "..AL["Templars"], "Templars" },
		{ AL["Abyssal Council"].." - "..AL["Dukes"], "Dukes" },
		{ AL["Abyssal Council"].." - "..AL["High Council"], "HighCouncil" },
	},
	["EthereumPrison"] = {
		{ AL["Armbreaker Huffaz"], "ArmbreakerHuffaz" },
		{ AL["Fel Tinkerer Zortan"], "FelTinkererZortan" },
		{ AL["Forgosh"], "Forgosh" },
		{ AL["Gul'bor"], "Gulbor" },
		{ AL["Malevus the Mad"], "MalevustheMad" },
		{ AL["Porfus the Gem Gorger"], "PorfustheGemGorger" },
		{ AL["Wrathbringer Laz-tarash"], "WrathbringerLaztarash" },
		{ AL["Bash'ir Landing Stasis Chambers"], "BashirStasisChambers" },
	},
	["Skettis"] = {
		{ AL["Darkscreecher Akkarai"], "DarkscreecherAkkarai" },
		{ AL["Gezzarak the Huntress"], "GezzaraktheHuntress" },
		{ AL["Karrog"], "Karrog" },
		{ AL["Terokk"], "Terokk" },
		{ AL["Vakkiz the Windrager"], "VakkiztheWindrager" },
	},
	["WoWFactions"] = {
		{ "", "Argent1" },
		{ BabbleFaction["Bloodsail Buccaneers"], "BloodsailHydraxian" },
		{ "", "AQBroodRings" },
		{ "", "Cenarion1" },
		{ BabbleFaction["Frostwolf Clan"], "AlteracFactions" },
		{ BabbleFaction["Gelkis Clan Centaur"], "MiscFactions" },
		{ BabbleFaction["Hydraxian Waterlords"], "BloodsailHydraxian" },
		{ BabbleFaction["Magram Clan Centaur"], "MiscFactions" },
		{ BabbleFaction["Stormpike Guard"], "AlteracFactions" },
		{ "", "Thorium1" },
		{ "", "Timbermaw" },
		{ BabbleFaction["Wintersaber Trainers"], "MiscFactions" },
		{ "", "Zandalar1" },
	},
	["BCFactions"] = {
		{ "", "Aldor1" },
		{ "", "Ashtongue1" },
		{ "", "CExpedition1" },
		{ "", "Consortium1" },
		{ "", "HonorHold1" },
		{ "", "KeepersofTime1" },
		{ "", "Kurenai1" },
		{ "", "LowerCity1" },
		{ "", "Maghar1" },
		{ "", "Netherwing1" },
		{ "", "Ogrila1" },
		{ "", "ScaleSands1" },
		{ "", "Scryer1" },
		{ "", "Shatar1" },
		{ "", "Skyguard1" },
		{ "", "SunOffensive1" },
		{ "", "Sporeggar1" },
		{ "", "Thrallmar1" },
		{ "", "Tranquillien1" },
		{ "", "VioletEye1" },
	},
	["WotLKFactions"] = {
		{ "", "AllianceVanguard1" },
		{ "", "ArgentCrusade" },
		{ "", "FrenzyheartTribe" },
		{ "", "HordeExpedition1" },
		{ "", "TheKaluak" },
		{ "", "KirinTor" },
		{ "", "KnightsoftheEbonBlade" },
		{ "", "TheOracles" },
		{ "", "TheSonsofHodir1" },
		{ "", "TheWyrmrestAccord" },
		{ "", "WinterfinRetreat" },
	},
	["BoEWorldEpics"] = {
		{ AtlasLoot_TableNames["WorldEpicsWrath1"][1], "WorldEpicsWrath1" },
		{ AtlasLoot_TableNames["WorldEpics4"][1], "WorldEpics4" },
		{ AtlasLoot_TableNames["WorldEpics3"][1], "WorldEpics3" },
		{ AtlasLoot_TableNames["WorldEpics2"][1], "WorldEpics2" },
		{ AtlasLoot_TableNames["WorldEpics1"][1], "WorldEpics1" },
	},
	["CraftSetBlacksmith"] = {
		{ AL["Imperial Plate"], "ImperialPlate" },
		{ AL["The Darksoul"], "TheDarksoul" },
		{ AL["Fel Iron Plate"], "FelIronPlate" },
		{ AL["Adamantite Battlegear"], "AdamantiteB" },
		{ AL["Flame Guard"], "FlameG" },
		{ AL["Enchanted Adamantite Armor"], "EnchantedAdaman" },
		{ AL["Khorium Ward"], "KhoriumWard" },
		{ AL["Faith in Felsteel"], "FaithFelsteel" },
		{ AL["Burning Rage"], "BurningRage" },
		{ AL["Bloodsoul Embrace"], "BloodsoulEmbrace" },
		{ AL["Fel Iron Chain"], "FelIronChain" },
	},
	["CraftSetLeatherwork"] = {
		{ AL["Volcanic Armor"], "VolcanicArmor" },
		{ AL["Ironfeather Armor"], "IronfeatherArmor" },
		{ AL["Stormshroud Armor"], "StormshroudArmor" },
		{ AL["Devilsaur Armor"], "DevilsaurArmor" },
		{ AL["Blood Tiger Harness"], "BloodTigerH" },
		{ AL["Primal Batskin"], "PrimalBatskin" },
		{ AL["Wild Draenish Armor"], "WildDraenishA" },
		{ AL["Thick Draenic Armor"], "ThickDraenicA" },
		{ AL["Fel Skin"], "FelSkin" },
		{ AL["Strength of the Clefthoof"], "SClefthoof" },
		{ AL["Primal Intent"], "PrimalIntent" },
		{ AL["Windhawk Armor"], "WindhawkArmor" },   
		{ AL["Green Dragon Mail"], "GreenDragonM" },
		{ AL["Blue Dragon Mail"], "BlueDragonM" },
		{ AL["Black Dragon Mail"], "BlackDragonM" },
		{ AL["Scaled Draenic Armor"], "ScaledDraenicA" },
		{ AL["Felscale Armor"], "FelscaleArmor" },
		{ AL["Felstalker Armor"], "FelstalkerArmor" },
		{ AL["Fury of the Nether"], "NetherFury" },
		{ AL["Netherscale Armor"], "NetherscaleArmor" },
		{ AL["Netherstrike Armor"], "NetherstrikeArmor" },
	},
	["CraftSetTailor"] = {
		{ AL["Bloodvine Garb"], "BloodvineG" },
		{ AL["Netherweave Vestments"], "NeatherVest" },
		{ AL["Imbued Netherweave"], "ImbuedNeather" },
		{ AL["Arcanoweave Vestments"], "ArcanoVest" },
		{ AL["The Unyielding"], "TheUnyielding" },
		{ AL["Whitemend Wisdom"], "WhitemendWis" },
		{ AL["Spellstrike Infusion"], "SpellstrikeInfu" },
		{ AL["Battlecast Garb"], "BattlecastG" },
		{ AL["Soulcloth Embrace"], "SoulclothEm" },
		{ AL["Primal Mooncloth"], "PrimalMoon" },
		{ AL["Shadow's Embrace"], "ShadowEmbrace" },
		{ AL["Wrath of Spellfire"], "SpellfireWrath" },
	},
	["DungeonSets12"] = {
		{ "", "T0Druid" },
		{ "", "T0Hunter" },
		{ "", "T0Mage" },
		{ "", "T0Paladin" },
		{ "", "T0Priest" },
		{ "", "T0Rogue" },
		{ "", "T0Shaman" },
		{ "", "T0Warlock" },
		{ "", "T0Warrior" },
	},
	["DungeonSets3"] = {
		{ "", "DS3Cloth" },
		{ "", "DS3Leather" },
		{ "", "DS3Mail" },
		{ "", "DS3Plate" },
	},
	["BadgeofJusticeRewards"] = {
		{ AtlasLoot_TableNames["HardModeArena"][1], "HardModeArena" },
		{ AtlasLoot_TableNames["HardModeCloth"][1], "HardModeCloth" },
		{ AtlasLoot_TableNames["HardModeLeather"][1], "HardModeLeather" },
		{ AtlasLoot_TableNames["HardModeMail"][1], "HardModeMail" },
		{ AtlasLoot_TableNames["HardModePlate"][1], "HardModePlate" },
		{ AtlasLoot_TableNames["HardModeCloaks"][1], "HardModeCloaks" },
		{ AtlasLoot_TableNames["HardModeResist"][1], "HardModeResist" },
		{ AtlasLoot_TableNames["HardModeAccessories"][1], "HardModeAccessories" },
		{ AtlasLoot_TableNames["HardModeRelic"][1], "HardModeRelic" },
		{ AtlasLoot_TableNames["HardModeWeapons"][1], "HardModeWeapons" },
	},
	["Pre60Sets"] = {
		{ AL["Bloodmail Regalia"], "VWOWScholo" },
		{ AL["Cadaverous Garb"], "VWOWScholo" },
		{ AL["Chain of the Scarlet Crusade"], "VWOWSets1" },
		{ AL["Dal'Rend's Arms"], "VWOWSets3" },
		{ AL["Deathbone Guardian"], "VWOWScholo" },
		{ AL["Defias Leather"], "VWOWSets1" },
		{ AL["Embrace of the Viper"], "VWOWSets1" },
		{ AL["Ironweave Battlesuit"], "VWOWSets2" },
		{ AL["Necropile Raiment"], "VWOWScholo" },
		{ AL["Primal Blessing"], "VWOWZulGurub" },
		{ AL["Shard of the Gods"], "VWOWSets3" },
		{ AL["Spider's Kiss"], "VWOWSets3" },
		{ AL["Spirit of Eskhandar"], "VWOWSets3" },
		{ AL["The Gladiator"], "VWOWSets1" },
		{ AL["The Postmaster"], "VWOWSets2" },
		{ AL["The Twin Blades of Hakkari"], "VWOWZulGurub" },
		{ AL["Zul'Gurub Rings"], "VWOWZulGurub" },
		{ AL["Latro's Flurry"], "TBCSets" },
		{ AL["The Twin Stars"], "TBCSets" },
		{ AL["The Twin Blades of Azzinoth"], "TBCSets" },
	},
	["T1T2Sets"] = {
		{ "", "T1T2Druid" },
		{ "", "T1T2Hunter" },
		{ "", "T1T2Mage" },
		{ "", "T1T2Paladin" },
		{ "", "T1T2Priest" },
		{ "", "T1T2Rogue" },
		{ "", "T1T2Shaman" },
		{ "", "T1T2Warlock" },
		{ "", "T1T2Warrior" },
	},
	["T3Sets"] = {
		{ "", "T3Druid" },
		{ "", "T3Hunter" },
		{ "", "T3Mage" },
		{ "", "T3Paladin" },
		{ "", "T3Priest" },
		{ "", "T3Rogue" },
		{ "", "T3Shaman" },
		{ "", "T3Warlock" },
		{ "", "T3Warrior" },
	},
	["T456Sets"] = {
		{ "", "T456DruidBalance" },
		{ "", "T456DruidFeral" },
		{ "", "T456DruidRestoration" },
		{ "", "T456Hunter" },
		{ "", "T456Mage" },
		{ "", "T456PaladinHoly" },
		{ "", "T456PaladinProtection" },
		{ "", "T456PaladinRetribution" },
		{ "", "T456PriestHoly" },
		{ "", "T456PriestShadow" },
		{ "", "T456Rogue" },
		{ "", "T456ShamanElemental" },
		{ "", "T456ShamanEnhancement" },
		{ "", "T456ShamanRestoration" },
		{ "", "T456Warlock" },
		{ "", "T456WarriorFury" },
		{ "", "T456WarriorProtection" },
	},
	["Naxx10Sets"] = {
		{ "", "NaxxDeathKnightDPS" },
		{ "", "NaxxDeathKnightTank" },
		{ "", "NaxxDruidBalance" },
		{ "", "NaxxDruidFeral" },
		{ "", "NaxxDruidRestoration" },
		{ "", "NaxxHunter" },
		{ "", "NaxxMage" },
		{ "", "NaxxPaladinHoly" },
		{ "", "NaxxPaladinProtection" },
		{ "", "NaxxPaladinRetribution" },
		{ "", "NaxxPriestHoly" },
		{ "", "NaxxPriestShadow" },
		{ "", "NaxxRogue" },
		{ "", "NaxxShamanElemental" },
		{ "", "NaxxShamanEnhancement" },
		{ "", "NaxxShamanRestoration" },
		{ "", "NaxxWarlock" },
		{ "", "NaxxWarriorFury" },
		{ "", "NaxxWarriorProtection" },
	},
	["ArenaPvPRewards"] = {
		{ BabbleClass["Druid"].." - "..AL["Feral"], "ArenaDruidFeral" },
		{ BabbleClass["Druid"].." - "..AL["Balance"], "ArenaDruidBalance" },
		{ BabbleClass["Druid"].." - "..AL["Restoration"], "ArenaDruidRestoration" },
		{ BabbleClass["Hunter"], "ArenaHunter" },
		{ BabbleClass["Mage"], "ArenaMage" },
		{ BabbleClass["Paladin"].." - "..AL["Protection"], "ArenaPaladinProtection" },
		{ BabbleClass["Paladin"].." - "..AL["Retribution"], "ArenaPaladinRetribution" },
		{ BabbleClass["Paladin"].." - "..AL["Holy"], "ArenaPaladinHoly" },
		{ BabbleClass["Priest"].." - "..AL["Holy"], "ArenaPriestHoly" },
		{ BabbleClass["Priest"].." - "..AL["Shadow"], "ArenaPriestShadow" },
		{ BabbleClass["Rogue"], "ArenaRogue" },
		{ BabbleClass["Shaman"].." - "..AL["Enhancement"], "ArenaShamanEnhancement" },
		{ BabbleClass["Shaman"].." - "..AL["Elemental"], "ArenaShamanElemental" },
		{ BabbleClass["Shaman"].." - "..AL["Restoration"], "ArenaShamanRestoration" },
		{ BabbleClass["Warlock"].." - "..AL["Demonology"], "ArenaWarlockDemonology" },
		{ BabbleClass["Warlock"].." - "..AL["Destruction"], "ArenaWarlockDestruction" },
		{ BabbleClass["Warrior"], "ArenaWarrior" },
		{ "", "Arena2Weapons1" },
		{ "", "Arena3Weapons1" },
		{ "", "Arena4Weapons1" },
	},
	["AVRewards"] = {
		{ AL["Misc. Rewards"], "AVMisc" },
		{ AL["Superior Rewards"], "AVBlue" },
		{ AL["Epic Rewards"], "AVPurple" },
	},
	["ABRewards"] = {
		{ AL["Misc. Rewards"], "ABMisc" },
		{ AtlasLoot_TableNames["AB20291"][1], "AB20291" },
		{ AtlasLoot_TableNames["AB3039"][1], "AB3039" },
		{ AtlasLoot_TableNames["AB40491"][1], "AB40491" },
		{ AtlasLoot_TableNames["AB5059"][1], "AB5059" },
		{ AtlasLoot_TableNames["AB60"][1], "AB60" },
	},
	["ABSets"] = {
		{ AtlasLoot_TableNames["ABSets1"][1], "ABSets1" },
		{ AtlasLoot_TableNames["ABSets2"][1], "ABSets2" },
		{ AtlasLoot_TableNames["ABSets3"][1], "ABSets3" },
	},
	["PvPNonSetEpic"] = {
		{ AtlasLoot_TableNames["PvP70NonSet1"][1], "PvP70NonSet1" },
		{ AtlasLoot_TableNames["PvP70NonSet2"][1], "PvP70NonSet2" },
		{ AtlasLoot_TableNames["PvP70NonSet3"][1], "PvP70NonSet3" },
		{ AtlasLoot_TableNames["PvP70NonSet4"][1], "PvP70NonSet4" },
		{ AtlasLoot_TableNames["PvP70NonSet5"][1], "PvP70NonSet5" },
	},
	["PvPLvl60Rewards"] = {
		{ BabbleClass["Druid"], "PVPDruid" },
		{ BabbleClass["Hunter"], "PVPHunter" },
		{ BabbleClass["Mage"], "PVPMage" },
		{ BabbleClass["Paladin"], "PVPPaladin" },
		{ BabbleClass["Priest"], "PVPPriest" },
		{ BabbleClass["Rogue"], "PVPRogue" },
		{ BabbleClass["Shaman"], "PVPShaman" },
		{ BabbleClass["Warlock"], "PVPWarlock" },
		{ BabbleClass["Warrior"], "PVPWarrior" },
		{ AtlasLoot_TableNames["PVPWeapons1"][1], "PVPWeapons1" },
		{ AtlasLoot_TableNames["PvP60Accessories1"][1], "PvP60Accessories1" },
	},
	["PvPLvl70Rewards"] = {
		{ "", "PVP70RepCloth" },
		{ "", "PVP70RepLeather" },
		{ "", "PVP70RepMail" },
		{ "", "PVP70RepPlate" },
		{ AL["PvP Non-Set Epics"], "PvP70NonSet1" },
		{ AtlasLoot_TableNames["PvP70Accessories1"][1], "PvP70Accessories1" },
	},
	["PvPLvl80Rewards"] = {
		{ "", "PvP80DeathKnight" },
		{ "", "PvP80DruidFeral" },
		{ "", "PvP80DruidBalance" },
		{ "", "PvP80DruidRestoration" },
		{ "", "PvP80Hunter" },
		{ "", "PvP80Mage" },
		{ "", "PvP80PaladinRetribution" },
		{ "", "PvP80PaladinHoly" },
		{ "", "PvP80PriestHoly" },
		{ "", "PvP80PriestShadow" },
		{ "", "PvP80Rogue" },
		{ "", "PvP80ShamanEnhancement" },
		{ "", "PvP80ShamanElemental" },
		{ "", "PvP80ShamanRestoration" },
		{ "", "PvP80Warlock" },
		{ "", "PvP80Warrior" },
		{ AtlasLoot_TableNames["PvP80NonSet1"][1], "PvP80NonSet1" },
		--{ "", "PvP80Weapons1" },
		{ "", "DeadlyGladiatorWeapons1" },
		{ "", "PvP80Jewelcrafting" },
	},
	["Pets"] = {
		{ AtlasLoot_TableNames["Pets1"][1], "Pets1" },
		{ AtlasLoot_TableNames["Pets2"][1], "Pets2" },
		{ AtlasLoot_TableNames["Pets3"][1], "Pets3" },
		{ AtlasLoot_TableNames["Pets4"][1], "Pets4" },
		{ AtlasLoot_TableNames["Pets5"][1], "Pets5" },
	},
	["MountsClassic"] = {
		{ AtlasLoot_TableNames["Mounts11"][1], "Mounts11" },
		{ AtlasLoot_TableNames["Mounts12"][1], "Mounts12" },
		{ AtlasLoot_TableNames["Mounts13"][1], "Mounts13" },
	},
	["MountsBC"] = {
		{ AtlasLoot_TableNames["Mounts21"][1], "Mounts21" },
		{ AtlasLoot_TableNames["Mounts22"][1], "Mounts22" },
		{ AtlasLoot_TableNames["Mounts23"][1], "Mounts23" },
		{ AtlasLoot_TableNames["Mounts24"][1], "Mounts24" },
		{ AtlasLoot_TableNames["Mounts25"][1], "Mounts25" },
	},
	["MountsLichKing"] = {
		{ AtlasLoot_TableNames["Mounts31"][1], "Mounts31" },
		{ AtlasLoot_TableNames["Mounts32"][1], "Mounts32" },
	},
	["WSGRewards"] = {
		{ AL["Misc. Rewards"], "WSGMisc" },
		{ AtlasLoot_TableNames["WSG1019"][1], "WSG1019" },
		{ AtlasLoot_TableNames["WSG2029"][1], "WSG2029" },
		{ AtlasLoot_TableNames["WSG3039"][1], "WSG3039" },
		{ AtlasLoot_TableNames["WSG4049"][1], "WSG4049" },
		{ AtlasLoot_TableNames["WSG5059"][1], "WSG5059" },
		{ AtlasLoot_TableNames["WSG60"][1], "WSG60" },
	},
	["Alchemy"] = {
		{ AL["Battle Elixirs"], "AlchemyBattleElixir1" },
		{ AL["Guardian Elixirs"], "AlchemyGuardianElixir1" },
		{ AL["Potions"], "AlchemyPotion1" },
		{ AL["Transmutes"], "AlchemyTransmute1" },
		{ AL["Flasks"], "AlchemyFlask1" },
		{ AL["Miscellaneous"], "AlchemyMisc1" },
	},
	["BlackSmithing"] = {
		{ BabbleInventory["Armor"].." - "..AL["Original WoW"], "SmithingArmorOld1" },
		{ BabbleInventory["Armor"].." - "..AL["Burning Crusade"], "SmithingArmorBC1" },
		{ BabbleInventory["Armor"].." - "..AL["Wrath of the Lich King"], "SmithingArmorWrath1" },
		{ BabbleInventory["Weapon"].." - "..AL["Original WoW"], "SmithingWeaponOld1" },
		{ BabbleInventory["Weapon"].." - "..AL["Burning Crusade"], "SmithingWeaponBC1" },
		{ BabbleInventory["Weapon"].." - "..AL["Wrath of the Lich King"], "SmithingWeaponWrath1" },
		{ AL["Item Enhancements"], "SmithingEnhancement1" },
		{ AL["Miscellaneous"], "SmithingMisc1" },
		{ AtlasLoot_TableNames["Armorsmith1"][1], "Armorsmith1" },
		{ AtlasLoot_TableNames["Weaponsmith1"][1], "Weaponsmith1" },
		{ AtlasLoot_TableNames["Axesmith1"][1], "Axesmith1" },
		{ AtlasLoot_TableNames["Hammersmith1"][1], "Hammersmith1" },
		{ AtlasLoot_TableNames["Swordsmith1"][1], "Swordsmith1" },
	},
	["Enchanting"] = {
		{ "", "EnchantingBoots1" },
		{ "", "EnchantingBracer1" },
		{ "", "EnchantingChest1" },
		{ "", "EnchantingCloak1" },
		{ "", "EnchantingGloves1" },
		{ "", "EnchantingRing1" },
		{ "", "EnchantingShield1" },
        { "", "EnchantingStaff1" },
		{ "", "Enchanting2HWeapon1" },
		{ "", "EnchantingWeapon1" },
		{ "", "EnchantingMisc1" },
	},
	["Engineering"] = {
		{ AL["Ammunition"], "EngineeringAmmo1" },
		{ BabbleInventory["Armor"], "EngineeringArmor1" },
		{ AL["Explosives"], "EngineeringExplosives1" },
		{ AL["Item Enhancements"], "EngineeringItemEnhancements1" },
		{ AL["Miscellaneous"], "EngineeringMisc1" },
		{ AL["Reagents"], "EngineeringReagents1" },
		{ BabbleInventory["Weapon"], "EngineeringWeapon1" },
		{ AtlasLoot_TableNames["Gnomish1"][1], "Gnomish1" },
		{ AtlasLoot_TableNames["Goblin1"][1], "Goblin1" },
	},
	["Inscription"] = {
		{ AL["Miscellaneous"], "Inscription_Misc1" },
		{ AL["Off-Hand Items"], "Inscription_OffHand1" },
		{ AL["Reagents"], "Inscription_Reagents1" },
		{ AL["Scrolls"], "Inscription_Scrolls1" },
		{ AL["Major Glyph"].." - "..BabbleClass["Deathknight"], "Inscription_DeathKnightMajor1" },
		{ AL["Minor Glyph"].." - "..BabbleClass["Deathknight"], "Inscription_DeathKnightMinor1" },
		{ AL["Major Glyph"].." - "..BabbleClass["Druid"], "Inscription_DruidMajor1" },
		{ AL["Minor Glyph"].." - "..BabbleClass["Druid"], "Inscription_DruidMinor1" },
		{ AL["Major Glyph"].." - "..BabbleClass["Hunter"], "Inscription_HunterMajor1" },
		{ AL["Minor Glyph"].." - "..BabbleClass["Hunter"], "Inscription_HunterMinor1" },
		{ AL["Major Glyph"].." - "..BabbleClass["Mage"], "Inscription_MageMajor1" },
		{ AL["Minor Glyph"].." - "..BabbleClass["Mage"], "Inscription_MageMinor1" },
		{ AL["Major Glyph"].." - "..BabbleClass["Paladin"], "Inscription_PaladinMajor1" },
		{ AL["Minor Glyph"].." - "..BabbleClass["Paladin"], "Inscription_PaladinMinor1" },
		{ AL["Major Glyph"].." - "..BabbleClass["Priest"], "Inscription_PriestMajor1" },
		{ AL["Minor Glyph"].." - "..BabbleClass["Priest"], "Inscription_PriestMinor1" },
		{ AL["Major Glyph"].." - "..BabbleClass["Rogue"], "Inscription_RogueMajor1" },
		{ AL["Minor Glyph"].." - "..BabbleClass["Rogue"], "Inscription_RogueMinor1" },
		{ AL["Major Glyph"].." - "..BabbleClass["Shaman"], "Inscription_ShamanMajor1" },
		{ AL["Minor Glyph"].." - "..BabbleClass["Shaman"], "Inscription_ShamanMinor1" },
		{ AL["Major Glyph"].." - "..BabbleClass["Warlock"], "Inscription_WarlockMajor1" },
		{ AL["Minor Glyph"].." - "..BabbleClass["Warlock"], "Inscription_WarlockMinor1" },
		{ AL["Major Glyph"].." - "..BabbleClass["Warrior"], "Inscription_WarriorMajor1" },
		{ AL["Minor Glyph"].." - "..BabbleClass["Warrior"], "Inscription_WarriorMinor1" },
	},
	["Jewelcrafting"] = {
		{ BabbleInventory["Red"].." "..BabbleInventory["Gem"], "JewelRed1" },
		{ BabbleInventory["Blue"].." "..BabbleInventory["Gem"], "JewelBlue1" },
		{ BabbleInventory["Yellow"].." "..BabbleInventory["Gem"], "JewelYellow1" },
		{ BabbleInventory["Green"].." "..BabbleInventory["Gem"], "JewelGreen1" },
		{ BabbleInventory["Orange"].." "..BabbleInventory["Gem"], "JewelOrange1" },
		{ BabbleInventory["Purple"].." "..BabbleInventory["Gem"], "JewelPurple1" },
		{ BabbleInventory["Meta"].." "..BabbleInventory["Gem"], "JewelMeta1" },
		{ BabbleInventory["Prismatic"].." "..BabbleInventory["Gem"], "JewelPrismatic1" },
		{ BabbleInventory["Neck"], "JewelNeck1" },
		{ BabbleInventory["Ring"], "JewelRing1" },
		{ BabbleInventory["Trinket"], "JewelTrinket1" },
		{ AL["Miscellaneous"], "JewelMisc1" },
	},
	["Leatherworking"] = {
		{ AL["Leather Armor"].." - "..AL["Original WoW"], "LeatherLeatherArmorOld1" },
		{ AL["Leather Armor"].." - "..AL["Burning Crusade"], "LeatherLeatherArmorBC1" },
		{ AL["Leather Armor"].." - "..AL["Wrath of the Lich King"], "LeatherLeatherArmorWrath1" },
		{ AL["Mail Armor"].." - "..AL["Original WoW"], "LeatherMailArmorOld1" },
		{ AL["Mail Armor"].." - "..AL["Burning Crusade"], "LeatherMailArmorBC1" },
		{ AL["Mail Armor"].." - "..AL["Wrath of the Lich King"], "LeatherMailArmorWrath1" },
		{ AL["Cloaks"], "LeatherCloaks1" },
		{ AL["Item Enhancements"], "LeatherItemEnhancement1" },
		{ AL["Quivers and Ammo Pouches"], "LeatherQuiversPouches1" },
		{ AL["Drums, Bags and Misc."], "LeatherDrumsBagsMisc1" },
		{ AtlasLoot_TableNames["Dragonscale1"][1], "Dragonscale1" },
		{ AtlasLoot_TableNames["Elemental1"][1], "Elemental1" },
		{ AtlasLoot_TableNames["Tribal1"][1], "Tribal1" },
		{ BabbleInventory["Leather"], "LeatherLeather1" },
	},
	["Tailoring"] = {
		{ AL["Cloth Armor"].." - "..AL["Original WoW"], "TailoringArmorOld1" },
		{ AL["Cloth Armor"].." - "..AL["Burning Crusade"], "TailoringArmorBC1" },
		{ AL["Cloth Armor"].." - "..AL["Wrath of the Lich King"], "TailoringArmorWotLK1" },
		{ AL["Bags"], "TailoringBags1" },
		{ AL["Miscellaneous"], "TailoringMisc1" },
		{ AL["Shirts"], "TailoringShirts1" },
		{ AtlasLoot_TableNames["Mooncloth1"][1], "Mooncloth1" },
		{ AtlasLoot_TableNames["Shadoweave1"][1], "Shadoweave1" },
		{ AtlasLoot_TableNames["Spellfire1"][1], "Spellfire1" },
	},
	["CraftingDaily"] = {
		{ "", "JewelcraftingDaily" },
		{ "", "CookingDaily" },
	},
};